==> ktp-desktop-applets-21.04.3.tar.xz: ktp-desktop-applets-21.04.3/person/org.kde.person/metadata.desktop.cmake <==
[Desktop Entry]
Name=Person
Name[ar]=شخص
Name[ca]=Persona
Name[ca@valencia]=Persona
Name[cs]=Osoba
Name[da]=Person
Name[de]=Person
Name[el]=Πρόσωπο
Name[en_GB]=Person
Name[es]=Persona
Name[et]=Isik
Name[eu]=Pertsona
Name[fi]=Henkilö
Name[fr]=Personne
Name[gl]=Persoa
Name[hi]=व्यक्ति
Name[hu]=Partner
Name[ia]=Persona
Name[it]=Persona
Name[ko]=사람
Name[lt]=Asmuo
Name[nl]=Persoon
Name[nn]=Person
Name[pl]=Ludzie
Name[pt]=Pessoa
Name[pt_BR]=Pessoa
Name[ro]=Persoană
Name[ru]=Человек
Name[sk]=Osoba
Name[sl]=Oseba
Name[sr]=Особа
Name[sr@ijekavian]=Особа
Name[sr@ijekavianlatin]=Osoba
Name[sr@latin]=Osoba
Name[sv]=Person
Name[tr]=Kişi
Name[uk]=Особа
Name[x-test]=xxPersonxx
Name[zh_CN]=个人
Name[zh_TW]=人物
Comment=Makes a person easily accessible
Comment[ca]=Fa accessible una persona amb facilitat
Comment[ca@valencia]=Fa accessible una persona amb facilitat
Comment[cs]=Usnadňuje přístup k osobám
Comment[da]=Gør en person nemt tilgængelig
Comment[de]=Ermöglicht den einfachen Zugriff auf eine Person
Comment[el]=Καθιστά ένα πρόσωπο προσβάσιμο εύκολα
Comment[en_GB]=Makes a person easily accessible
Comment[es]=Hace a una persona fácilmente accesible
Comment[et]=Isiku hõlpsasti kättesaadavaks muutmine
Comment[eu]=Pertsona bat irisgarria izatea errazten du
Comment[fi]=Helppo pääsy henkilöön
Comment[fr]=Rendre une personne facilement accessible
Comment[gl]=Permite acceder facilmente a unha persoa.
Comment[hi]=किसी भी व्यक्ति को सरलता से सुलभ बनाएँ
Comment[hu]=Egyszerűbben elérhetővé tesz egy partnert
Comment[ia]=Face un persona facilmente accessibile
Comment[it]=Rende una persona facilmente accessibile
Comment[ko]=특정 사람과 빠르게 대화합니다
Comment[lt]=Leidžia greitai pasiekti asmenį
Comment[nl]=Maakt een persoon gemakkelijk toegankelijk
Comment[nn]=Gjer ein person lett tilgjengeleg
Comment[pl]=Czyni ludzi łatwo dostępnymi
Comment[pt]=Torna uma pessoa facilmente acessível
Comment[pt_BR]=Torna uma pessoa facilmente acessível
Comment[ro]=Face o persoană să fie accesibilă ușor
Comment[ru]=Виджет для быстрого начала разговора с человеком
Comment[sk]=Urobí osobu ľahko prístupnú
Comment[sl]=Napravi osebo enostavno dostopno
Comment[sr]=Чини особу лако доступном
Comment[sr@ijekavian]=Чини особу лако доступном
Comment[sr@ijekavianlatin]=Čini osobu lako dostupnom
Comment[sr@latin]=Čini osobu lako dostupnom
Comment[sv]=Gör en person lätt tillgänglig
Comment[tr]=Bir kişiyi kolay erişilebilir yapar
Comment[uk]=Спрощує доступ до особи
Comment[x-test]=xxMakes a person easily accessiblexx
Comment[zh_CN]=访问他人变得简单
Comment[zh_TW]=輕鬆與人互動

Icon=applications-system
Type=Service
X-KDE-ServiceTypes=Plasma/Applet
X-Plasma-API=declarativeappletscript

X-KDE-PluginInfo-Author=Aleix Pol Gonzalez
X-KDE-PluginInfo-Email=aleixpol@blue-systems.com
X-KDE-PluginInfo-Name=person
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@
X-KDE-PluginInfo-Website=http://plasma.kde.org/
X-KDE-PluginInfo-Category=Utilities
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Name=org.kde.person

X-Plasma-MainScript=ui/main.qml
X-Plasma-Requires-LaunchApp=Unused
X-Plasma-DefaultSize=200,300

==> ktp-desktop-applets-21.08.0.tar.xz: ktp-desktop-applets-21.08.0/person/org.kde.person/metadata.desktop.cmake <==
[Desktop Entry]
Name=Person
Name[ar]=شخص
Name[ca]=Persona
Name[ca@valencia]=Persona
Name[cs]=Osoba
Name[da]=Person
Name[de]=Person
Name[el]=Πρόσωπο
Name[en_GB]=Person
Name[es]=Persona
Name[et]=Isik
Name[eu]=Pertsona
Name[fi]=Henkilö
Name[fr]=Personne
Name[gl]=Persoa
Name[hi]=व्यक्ति
Name[hu]=Partner
Name[ia]=Persona
Name[it]=Persona
Name[ko]=사람
Name[lt]=Asmuo
Name[nl]=Persoon
Name[nn]=Person
Name[pl]=Ludzie
Name[pt]=Pessoa
Name[pt_BR]=Pessoa
Name[ro]=Persoană
Name[ru]=Человек
Name[sk]=Osoba
Name[sl]=Oseba
Name[sr]=Особа
Name[sr@ijekavian]=Особа
Name[sr@ijekavianlatin]=Osoba
Name[sr@latin]=Osoba
Name[sv]=Person
Name[tr]=Kişi
Name[uk]=Особа
Name[x-test]=xxPersonxx
Name[zh_CN]=个人
Name[zh_TW]=人物
Comment=Makes a person easily accessible
Comment[ca]=Fa accessible una persona amb facilitat
Comment[ca@valencia]=Fa accessible una persona amb facilitat
Comment[cs]=Usnadňuje přístup k osobám
Comment[da]=Gør en person nemt tilgængelig
Comment[de]=Ermöglicht den einfachen Zugriff auf eine Person
Comment[el]=Καθιστά ένα πρόσωπο προσβάσιμο εύκολα
Comment[en_GB]=Makes a person easily accessible
Comment[es]=Hace a una persona fácilmente accesible
Comment[et]=Isiku hõlpsasti kättesaadavaks muutmine
Comment[eu]=Pertsona bat irisgarria izatea errazten du
Comment[fi]=Helppo pääsy henkilöön
Comment[fr]=Rendre une personne facilement accessible
Comment[gl]=Permite acceder facilmente a unha persoa.
Comment[hi]=किसी भी व्यक्ति को सरलता से प्राप्य बनाएँ
Comment[hu]=Egyszerűbben elérhetővé tesz egy partnert
Comment[ia]=Face un persona facilmente accessibile
Comment[it]=Rende una persona facilmente accessibile
Comment[ko]=특정 사람과 빠르게 대화합니다
Comment[lt]=Leidžia greitai pasiekti asmenį
Comment[nl]=Maakt een persoon gemakkelijk toegankelijk
Comment[nn]=Gjer ein person lett tilgjengeleg
Comment[pl]=Czyni ludzi łatwo dostępnymi
Comment[pt]=Torna uma pessoa facilmente acessível
Comment[pt_BR]=Torna uma pessoa facilmente acessível
Comment[ro]=Face o persoană să fie accesibilă ușor
Comment[ru]=Виджет для быстрого начала разговора с человеком
Comment[sk]=Urobí osobu ľahko prístupnú
Comment[sl]=Napravi osebo enostavno dostopno
Comment[sr]=Чини особу лако доступном
Comment[sr@ijekavian]=Чини особу лако доступном
Comment[sr@ijekavianlatin]=Čini osobu lako dostupnom
Comment[sr@latin]=Čini osobu lako dostupnom
Comment[sv]=Gör en person lätt tillgänglig
Comment[tr]=Bir kişiyi kolay erişilebilir yapar
Comment[uk]=Спрощує доступ до особи
Comment[x-test]=xxMakes a person easily accessiblexx
Comment[zh_CN]=访问他人变得简单
Comment[zh_TW]=輕鬆與人互動

Icon=applications-system
Type=Service
X-KDE-ServiceTypes=Plasma/Applet
X-Plasma-API=declarativeappletscript

X-KDE-PluginInfo-Author=Aleix Pol Gonzalez
X-KDE-PluginInfo-Email=aleixpol@blue-systems.com
X-KDE-PluginInfo-Name=person
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@
X-KDE-PluginInfo-Website=http://plasma.kde.org/
X-KDE-PluginInfo-Category=Utilities
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Name=org.kde.person

X-Plasma-MainScript=ui/main.qml
X-Plasma-Requires-LaunchApp=Unused
X-Plasma-DefaultSize=200,300
